# `demosh`

## Installing `demosh`

To install `demosh` from source, you'll need Python 3.8.10 or higher,
[`flit`](https://flit.pypa.io/en/stable/) and `make`.

- Install `flit`, most likely with `python3 -m pip install flit`.
- Run `make install`.
